==> nextcloud-23.0.12p0.tgz: nextcloud/apps/support/l10n/sv.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Länk:",
    "Password:" : "Lösenord:",
    "Generating system report failed." : "Det gick inte att generera systemrapporten.",
    "Could not create folder \"System information\" to store generated report." : "Det gick inte att skapa mappen \"System information\" för att lagra skapad rapport.",
    "Could not create file \"%s\" to store generated report." : "Det gick inte att skapa filen \"%s\" för att lagra skapad rapport.",
    "Subscription notifications" : "Abonnemangsaviseringar",
    "Nextcloud Subscription" : "Nextcloud-abonnemang",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Din server har inget Nextcloud-abonnemang eller ditt abonnemang har löpt ut.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ditt Nextcloud-serverabonnemang täcker inte ditt antal användare.",
    "Your Nextcloud Subscription has expired!" : "Ditt Nextcloud-abonnemang har löpt ut!",
    "Your server has no Nextcloud Subscription" : "Din server har inget Nextcloud-abonnemang",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Din Nextcloud-server stöds inte av ett Nextcloud-företagsabonnemang.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "En Nextcloud Enterprise Subscription innebär att de ursprungliga utvecklarna bakom molnservern som du är värd för är 100% dedikerad till din framgång: säkerhet, skalbarhet, prestanda och funktionalitet i din tjänst!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Om din serverinställning bryts och anställda inte kan arbeta längre behöver du inte lita på att söka på ett forum på nätet efter en lösning. Du har direkt tillgång till våra erfarna ingenjörer!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Du har ett kontrakt med säljaren som ger tidig säkerhetsinformation, förmildrande omständigheter, rättningar och uppdateringar.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Om du behöver stanna längre på din nuvarande version utan störningar, behöver du inte köra programvara utan säkerhetsuppdateringar.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Du har den bästa kompetensen till hands för att hantera problem med prestanda och skalbarhet.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Du har åtkomst till rätt dokumentation och expertis för att snabbt svara på efterlevnadsfrågor eller leverera på GDPR, HIPAA och andra krav på lagstiftning.",
    "A subscription helps you get the most out of Nextcloud!" : "Ett abonnemang hjälper dig att få ut det mesta av Nextcloud!",
    "Learn more now" : "Läs mer nu",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Det här e-postmeddelandet skickades till alla administratörer av supportappen på din Nextcloud-instans till %1$s eftersom du har över %2$s registrerade användare.",
    "Your Nextcloud server Subscription is over limit" : "Ditt Nextcloud-serverabonnemang är över gränsen",
    "Dear admin," : "Kära administratör,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Ditt Nextcloud-abonnemang täcker inte antalet användare som för närvarande är aktiva på den här servern. Kontakta din Nextcloud-kontohanterare för att få ditt abonnemang uppdaterat!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s är din kontohanterare och kan nås på e-post via %2$s eller på telefon via %3$s.",
    "Thank you," : "Tack,",
    "Your Nextcloud team" : "Ditt Nextcloud-team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Det här e-postmeddelandet skickades till alla administratörer av supportappen på din Nextcloud-instans på %s eftersom du har fler användare än ditt abonnemang täcker.",
    "Your Nextcloud server Subscription is expired" : "Ditt Nextcloud-serverabonnemang har löpt ut",
    "Your Nextcloud server Subscription is expired!" : "Ditt Nextcloud-serverabonnemang har löpt ut!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Ditt Nextcloud-abonnemang har gått ut! Kontakta din Nextcloud-kontohanterare för att få ditt abonnemang uppdaterat!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Det här e-postmeddelandet skickades till alla administratörer av supportappen på din Nextcloud-instans på %s på grund av att din prenumeration löpt ut.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Få stöd och hjälp för ditt Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Supportappen täcker dig med direkt åtkomst till hjälp- och konsultresurser, dedikerade kontaktalternativ till din kontohanterare och en översikt över ditt företagsabonnemang.",
    "Basic subscription" : "Grundabonnemang",
    "Standard subscription" : "Standardabonnemang",
    "Premium subscription" : "Premiumabonnemang",
    "Géant subscription" : "Géant-abonnemang",
    "Silver partner subscription" : "Silverpartner-abonnemang",
    "Gold partner subscription" : "Guldpartner-abonnemang",
    "Subscription" : "Abonnemang",
    "Over subscription limit" : "Över abonnemangsgräns",
    "Valid subscription" : "Giltigt abonnemang",
    "Expired subscription" : "Utgångna abonnemang",
    "Subscription key:" : "Abonnemangsnyckel:",
    "Expires in: " : "Går ut om:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n week_::_%n weeks_" : ["%n vecka","%n veckor"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "For an unlimited amount of users" : "För ett obegränsat antal användare",
    "_For %n active users_::_For %n active users_" : ["För %n aktiva användare","För %n aktiva användare"],
    "_For %n users_::_For %n users_" : ["För %n användare","För %n användare"],
    "_currently at %n user_::_currently at %n users_" : ["för närvarande %n användare ","för närvarande%n användare"],
    "Includes support for %s" : "Inkluderar stöd för %s",
    "Includes support for %1$s & %2$s" : "Inkluderar stöd för %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inkluderar stöd för %1$s, %2$s & %3$s",
    "Update subscription key" : "Uppdatera abonnemangsnyckeln",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s är din kontohanterare. Tveka inte att kontakta oss om du har frågor angående din abonnemang.",
    "You can find answers to common question in our portal and also file support requests there." : "Du kan hitta svar på vanliga frågor i vår portal och även filsupportsförfrågningar där.",
    "Access Nextcloud portal" : "Gå till Nextcloud-portalen",
    "System information" : "System information",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Samla in systeminformation för supportärenden. Knappen nedan skapar en textfil i mappen \"System information\" och delar den som lösenordsskyddad offentlig länk. Länken är giltig i 2 veckor.",
    "Generate system report" : "Generera systemrapport",
    "Enterprise subscription recommended" : "Företagsabonnemang rekommenderas",
    "No active enterprise subscription" : "Inget aktivt företagsabonnemang",
    "Unsupported" : "Stöds inte",
    "This Nextcloud server has no Enterprise Subscription." : "Den här Nextcloud-servern har inget företagsabonnemang.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ett Nextcloud-företagsabonnemang hjälper dig att få ut det mesta av ditt Nextcloud, håller dina data säkra och din server arbetar tillförlitligt hela tiden.",
    "Advantages" : "Fördelar",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Åtkomst till Nextclouds tekniska expertis genom dokumentation och support",
    "Access to additional capabilities like Outlook integration, online office and more" : "Åtkomst till ytterligare funktioner som Outlook-integration, online office och mer",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Åtkomst till skalbarhetsexpertis och skalbarhetskapacitet för Files och Talk",
    "Optional branding, consulting, architecture advice" : "Valfritt varumärke, rådgivning, arkitekturrådgivning",
    "Confidential security notification service, mitigations, patches and advice" : "Konfidentiell säkerhetsanmälningstjänst, begränsningar, korrigeringar och råd",
    "Compliance certification, advice and documentation" : "Överensstämmelse certifiering, råd och dokumentation",
    "More information" : "Mer information",
    "Subscription benefits" : "Abonnemangsfördelar",
    "Pricing" : "Prissättning",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud är fri programvara som stöds av en mycket aktiv gemenskap. Vänligen registrera dig på forumet för att ställa frågor och diskutera med andra.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud använder GitHub som plattform för att samarbeta. Du kan skapa felrapporter direkt där.",
    "Chat" : "Chatt",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatta med oss på vår IRC-kanal #nextcloud på Freenode.",
    "Nextcloud forum" : "Nextcloud-forum",
    "Nextcloud at GitHub" : "Nextcloud på GitHub",
    "Open chat" : "Öppna chatt",
    "Subscription key" : "Abonnemangsnyckel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Om du har ett aktivt Nextcloud-abonnemang, vänligen ange din abonnemangsnyckel här.",
    "Learn more about an enterprise subscription." : "Läs mer om en företagsabonnemang.",
    "Set subscription key" : "Ange abonnemangsnyckel",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Prenumerationsinformationen kunde inte hämtas korrekt just nu. Ett nytt försök är schemalagd. Vänligen återkom senare.",
    "The subscription key was invalid." : "Abonnemangsnyckeln var ogiltig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Abonnemangsnyckeln kunde inte verifieras, eftersom den här servern inte har någon internetanslutning. Vänligen kontakta supportteamet för att få detta löst.",
    "The subscription key had an invalid format." : "Abonnemangsnyckeln hade ett ogiltigt format.",
    "While fetching the subscription information an error happened." : "När abonnemangsinformationen hämtades inträffade ett fel.",
    "News" : "Nyheter",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "För att få aktuell information vad som händer på Nextcloud, registrera dig för nyhetsbrevet och följ oss på våra sociala medier-konton.",
    "Like our Facebook page" : "Gilla vår Facebook-sida",
    "Follow us on Twitter" : "Följ oss på Twitter",
    "Check out our blog" : "Kolla in vår blogg",
    "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/support/l10n/sv.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Länk:",
    "Password:" : "Lösenord:",
    "Generating system report failed." : "Det gick inte att generera systemrapporten.",
    "Could not create folder \"System information\" to store generated report." : "Det gick inte att skapa mappen \"System information\" för att lagra skapad rapport.",
    "Could not create file \"%s\" to store generated report." : "Det gick inte att skapa filen \"%s\" för att lagra skapad rapport.",
    "Subscription notifications" : "Abonnemangsaviseringar",
    "Nextcloud Subscription" : "Nextcloud-abonnemang",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Din server har inget Nextcloud-abonnemang eller ditt abonnemang har löpt ut.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ditt Nextcloud-serverabonnemang täcker inte ditt antal användare.",
    "Your Nextcloud Subscription has expired!" : "Ditt Nextcloud-abonnemang har löpt ut!",
    "Your server has no Nextcloud Subscription" : "Din server har inget Nextcloud-abonnemang",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Din Nextcloud-server stöds inte av ett Nextcloud-företagsabonnemang.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Om din serverinställning bryts och anställda inte kan arbeta längre behöver du inte lita på att söka på ett forum på nätet efter en lösning. Du har direkt tillgång till våra erfarna ingenjörer!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Du har ett kontrakt med säljaren som ger tidig säkerhetsinformation, förmildrande omständigheter, rättningar och uppdateringar.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Om du behöver stanna längre på din nuvarande version utan störningar, behöver du inte köra programvara utan säkerhetsuppdateringar.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Du har den bästa kompetensen till hands för att hantera problem med prestanda och skalbarhet.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Du har åtkomst till rätt dokumentation och expertis för att snabbt svara på efterlevnadsfrågor eller leverera på GDPR, HIPAA och andra krav på lagstiftning.",
    "A subscription helps you get the most out of Nextcloud!" : "Ett abonnemang hjälper dig att få ut det mesta av Nextcloud!",
    "Learn more now" : "Läs mer nu",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Det här e-postmeddelandet skickades till alla administratörer av supportappen på din Nextcloud-instans till %1$s eftersom du har över %2$s registrerade användare.",
    "Your Nextcloud server Subscription is over limit" : "Ditt Nextcloud-serverabonnemang är över gränsen",
    "Dear admin," : "Kära administratör,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Ditt Nextcloud-abonnemang täcker inte antalet användare som för närvarande är aktiva på den här servern. Kontakta din Nextcloud-kontohanterare för att få ditt abonnemang uppdaterat!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s är din kontohanterare och kan nås på e-post via %2$s eller på telefon via %3$s.",
    "Thank you," : "Tack,",
    "Your Nextcloud team" : "Ditt Nextcloud-team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Det här e-postmeddelandet skickades till alla administratörer av supportappen på din Nextcloud-instans på %s eftersom du har fler användare än ditt abonnemang täcker.",
    "Your Nextcloud server Subscription is expired" : "Ditt Nextcloud-serverabonnemang har löpt ut",
    "Your Nextcloud server Subscription is expired!" : "Ditt Nextcloud-serverabonnemang har löpt ut!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Ditt Nextcloud-abonnemang har gått ut! Kontakta din Nextcloud-kontohanterare för att få ditt abonnemang uppdaterat!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Det här e-postmeddelandet skickades till alla administratörer av supportappen på din Nextcloud-instans på %s på grund av att din prenumeration löpt ut.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Få stöd och hjälp för ditt Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Supportappen täcker dig med direkt åtkomst till hjälp- och konsultresurser, dedikerade kontaktalternativ till din kontohanterare och en översikt över ditt företagsabonnemang.",
    "Basic subscription" : "Grundabonnemang",
    "Standard subscription" : "Standardabonnemang",
    "Premium subscription" : "Premiumabonnemang",
    "Géant subscription" : "Géant-abonnemang",
    "Silver partner subscription" : "Silverpartner-abonnemang",
    "Gold partner subscription" : "Guldpartner-abonnemang",
    "Subscription" : "Abonnemang",
    "Over subscription limit" : "Över abonnemangsgräns",
    "Valid subscription" : "Giltigt abonnemang",
    "Expired subscription" : "Utgångna abonnemang",
    "Subscription key:" : "Abonnemangsnyckel:",
    "Expires in: " : "Går ut om:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n week_::_%n weeks_" : ["%n vecka","%n veckor"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "For an unlimited amount of users" : "För ett obegränsat antal användare",
    "_For %n active users_::_For %n active users_" : ["För %n aktiva användare","För %n aktiva användare"],
    "_For %n users_::_For %n users_" : ["För %n användare","För %n användare"],
    "_currently at %n user_::_currently at %n users_" : ["för närvarande %n användare ","för närvarande%n användare"],
    "Includes support for %s" : "Inkluderar stöd för %s",
    "Includes support for %1$s & %2$s" : "Inkluderar stöd för %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inkluderar stöd för %1$s, %2$s & %3$s",
    "Update subscription key" : "Uppdatera abonnemangsnyckeln",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s är din kontohanterare. Tveka inte att kontakta oss om du har frågor angående din abonnemang.",
    "You can find answers to common question in our portal and also file support requests there." : "Du kan hitta svar på vanliga frågor i vår portal och även filsupportsförfrågningar där.",
    "Access Nextcloud portal" : "Gå till Nextcloud-portalen",
    "System information" : "System information",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Samla in systeminformation för supportärenden. Knappen nedan skapar en textfil i mappen \"System information\" och delar den som lösenordsskyddad offentlig länk. Länken är giltig i 2 veckor.",
    "Generate system report" : "Generera systemrapport",
    "Enterprise subscription recommended" : "Företagsabonnemang rekommenderas",
    "No active enterprise subscription" : "Inget aktivt företagsabonnemang",
    "Unsupported" : "Stöds inte",
    "This Nextcloud server has no Enterprise Subscription." : "Den här Nextcloud-servern har inget företagsabonnemang.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ett Nextcloud-företagsabonnemang hjälper dig att få ut det mesta av ditt Nextcloud, håller din data säker och din server arbetar tillförlitligt hela tiden.",
    "Advantages" : "Fördelar",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Åtkomst till Nextclouds tekniska expertis genom dokumentation och support",
    "Access to additional capabilities like Outlook integration, online office and more" : "Åtkomst till ytterligare funktioner som Outlook-integration, online office och mer",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Åtkomst till skalbarhetsexpertis och skalbarhetskapacitet för Files och Talk",
    "Optional branding, consulting, architecture advice" : "Valfritt varumärke, rådgivning, arkitekturrådgivning",
    "Confidential security notification service, mitigations, patches and advice" : "Konfidentiell säkerhetsanmälningstjänst, begränsningar, korrigeringar och råd",
    "Compliance certification, advice and documentation" : "Överensstämmelse certifiering, råd och dokumentation",
    "Get a quote" : "Begär offert",
    "More information" : "Mer information",
    "Subscription benefits" : "Abonnemangsfördelar",
    "Pricing" : "Prissättning",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud är fri programvara som stöds av en mycket aktiv gemenskap. Vänligen registrera dig på forumet för att ställa frågor och diskutera med andra.",
    "Nextcloud forum" : "Nextcloud-forum",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud använder GitHub som plattform för att samarbeta. Du kan skapa felrapporter direkt där.",
    "Nextcloud at GitHub" : "Nextcloud på GitHub",
    "Subscription key" : "Abonnemangsnyckel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Om du har ett aktivt Nextcloud-abonnemang, vänligen ange din abonnemangsnyckel här.",
    "Learn more about an enterprise subscription." : "Läs mer om en företagsabonnemang.",
    "Set subscription key" : "Ange abonnemangsnyckel",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Prenumerationsinformationen kunde inte hämtas korrekt just nu. Ett nytt försök är schemalagd. Vänligen återkom senare.",
    "The subscription key was invalid." : "Abonnemangsnyckeln var ogiltig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Abonnemangsnyckeln kunde inte verifieras, eftersom den här servern inte har någon internetanslutning. Vänligen kontakta supportteamet för att få detta löst.",
    "The subscription key had an invalid format." : "Abonnemangsnyckeln hade ett ogiltigt format.",
    "While fetching the subscription information an error happened." : "När abonnemangsinformationen hämtades inträffade ett fel.",
    "News" : "Nyheter",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "För att få aktuell information vad som händer på Nextcloud, registrera dig för nyhetsbrevet och följ oss på våra sociala medier-konton.",
    "Like our Facebook page" : "Gilla vår Facebook-sida",
    "Follow us on Twitter" : "Följ oss på Twitter",
    "Check out our blog" : "Kolla in vår blogg",
    "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev"
},
"nplurals=2; plural=(n != 1);");
